



if not exist %LIBRARY_LIB%\\gstreamer-1.0\\gstalpha.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\gstreamer-1.0\\gstdebug.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\gstreamer-1.0\\gstspectrum.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
gst-inspect-1.0 --plugin alpha
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
